@@ -39,5 +39,7 @@ except ImportError:
 
 try:
     from Quartz.QuickLookUI import *
-except ImportError:
+except ImportError, msg:
+    import traceback
+    traceback.print_exc()
     pass
