@@ -5,7 +5,7 @@ from Quartz.QuartzComposer import *
 class TestQCCompositionPickerPanel (TestCase):
         @min_os_level('10.5')
         def testConstants(self):
-            self.failUnlessIsInstance(QCCompositionPickerPanelDidSelectCompositionNotification, unicode)
+            self.assertIsInstance(QCCompositionPickerPanelDidSelectCompositionNotification, unicode)
 
 if __name__ == "__main__":
     main()
